@@ -6,11 +6,7 @@ import time
 from functools import partial
 
 from kubernetes_asyncio import watch
-from traitlets import Any
-from traitlets import Bool
-from traitlets import Dict
-from traitlets import Int
-from traitlets import Unicode
+from traitlets import Any, Bool, Dict, Int, Unicode
 from traitlets.config import LoggingConfigurable
 from urllib3.exceptions import ReadTimeoutError
 
@@ -120,8 +116,8 @@ class ResourceReflector(LoggingConfigurable):
         Name of class that represents the apigroup on which
         `list_method_name` is to be found.
 
-        Defaults to CoreV1Api, which has everything in the 'core' API group. If you want to watch Ingresses,
-        for example, you would have to use ExtensionsV1beta1Api
+        Defaults to CoreV1Api, which has everything in the 'core' API group. If
+        you want to watch Ingresses you would have to use NetworkingV1Api.
         """,
     )
 
